"""Generate asset price values for one day"""

from functools import cached_property

from ..row_generator import BaseRowGenerator

class RowGenerator(BaseRowGenerator):
    """Generate asset price values for one day"""

    def __init__(self, filler, todays_asset_prices):
        super().__init__(filler)
        self.todays_asset_prices = todays_asset_prices

    @property
    def values(self):
        """Values suitable for usage in a worksheet row"""

        return [
            self.todays_asset_prices_by_asset_pk.get(asset.pk)
            for asset in self.portfolio_assets_by_pk.values()
        ]

    @cached_property
    def todays_asset_prices_by_asset_pk(self):
        """Asset prices for the given date and assets, indexed by pk."""

        return {
            asset_price.asset_id: asset_price.closing_price
            for asset_price in self.todays_asset_prices
        }

    @property
    def portfolio_assets_by_pk(self):
        """
        Provide easy access to the portfolio assets, indexed by pk
        (which is a property of the filler).
        """

        return self.filler.portfolio_assets_by_pk
