"""Generate portfolio asset weights for one portfolio revision."""

from ..row_generator import BaseRowGenerator

class PortfolioAssetWeightsRowGenerator(BaseRowGenerator):
    """Generate portfolio asset weights for one portfolio revision."""

    def __init__(self, generator, revision):
        super().__init__(generator)
        self.revision = revision

    @property
    def values(self):
        """Values suitable for usage in a worksheet row"""

        weights_by_asset_pk = self.weights_by_asset_pk
        return [
            weights_by_asset_pk.get(asset.pk, 0)
            for asset in self.assets
        ]

    @property
    def weights_by_asset_pk(self):
        """The weights of each asset as a dict, indexed by asset pk."""

        return {
            asset.asset.pk: asset.weight
            for asset in self.revision_assets
        }

    @property
    def revision_assets(self):
        """An iterable of all PortfolioAssets of the revision."""

        return self.revision.portfolioasset_set.all()
