"""Generate portfolio results for one portfolio revision."""

from ..row_generator import BaseRowGenerator

class RevisionResultsRowGenerator(BaseRowGenerator):
    """Generate portfolio results for one portfolio revision."""

    def __init__(self, filler, revision_results):
        super().__init__(filler)
        self.revision_results = revision_results

    @property
    def values(self):
        """
        Values suitable for usage in a worksheet row: a value for each
        date for which we have any results for any revision of any
        participant. If the current portfolio does not have a value for
        a date, that value is None.
        """

        sharpe_ratios_by_date = self.sharpe_ratios_by_date
        return (
            sharpe_ratios_by_date.get(date, None)
            for date in self.results_dates
        )

    @property
    def sharpe_ratios_by_date(self):
        """
        Return all sharpe ratios for this revision as a dict, indexed by date.
        """

        return {
            revision_result['date']: revision_result['sharpe_ratio']
            for revision_result in self.revision_results
            if 'sharpe_ratio' in revision_result
        }

    @property
    def results_dates(self):
        """
        Provide easy access to the dates for which any results are known
        (which is a property of the filler).
        """

        return self.filler.results_dates
